WindowTitle = "Pyblish"  # Customize the window of the pyblish-lite window.
UseLabel = True  # Customize whether to show label names for plugins.

# Customize which tab to start on. Possible choices are: "artist", "overview"
# and "terminal".
InitialTab = "artist"
